==> yylivesdk4cloud-audiovideo-1.8.15-sources.jar: com/yy/yylivesdk4cloud/ThunderNotificationInside.java <==
package com.yy.yylivesdk4cloud;

/**
 * Created by dzz on 2018/8/27.
 */

public class ThunderNotificationInside {
    // 接口内部消息起始标记
    public static final int kYYLiveAPINotification_Start_Tag = 1000;

    // 媒体推送信息返回
    public static final int kYYLiveAPINotification_PublishVideoCfg = kYYLiveAPINotification_Start_Tag + 0;


    public static class PublishVideoCfg {
        private int mEncodeFrameRate;
        private int mEncodeBitrate;
        private int mEncodeResolutionWidth;
        private int mEncodeResolutionHeight;
        private int mEncodeType;
        private boolean mBHardwareEncoder;
        private boolean mBMirrorFrontCamera;
        private boolean mBPubToGroupAndName;
        private int mMode;
        private int mPlayType;
        private int mScreenOrientation;

        public PublishVideoCfg(int encodeFrameRate,
                               int encodeBitrate,
                               int encodeResolutionWidth,
                               int encodeResolutionHeight,
                               int encodeType,
                               boolean bHardwareEncoder,
                               boolean bMirrorFrontCamera,
                               boolean bPubToGroupAndName,
                               int mode,
                               int playType,
                               int screenOrientation
                               )
        {
            mEncodeFrameRate = encodeFrameRate;
            mEncodeBitrate = encodeBitrate;
            mEncodeResolutionWidth = encodeResolutionWidth;
            mEncodeResolutionHeight = encodeResolutionHeight;
            mEncodeType = encodeType;
            mBHardwareEncoder = bHardwareEncoder;
            mBMirrorFrontCamera = bMirrorFrontCamera;
            mBPubToGroupAndName = bPubToGroupAndName;
            mMode = mode;
            mPlayType = playType;
            mScreenOrientation = screenOrientation;
        }

        public int getEncodeFrameRate() { return mEncodeFrameRate;}
        public int getEncodeBitrate() { return mEncodeBitrate;}
        public int getEncodeResolutionWidth() { return mEncodeResolutionWidth;}
        public int getEncodeResolutionHeight() { return mEncodeResolutionHeight;}
        public int getEncodeType() { return mEncodeType;}
        public boolean isHardwareEncoder() { return mBHardwareEncoder; }
        public boolean isMirrorFrontCamera() { return mBMirrorFrontCamera; }
        public boolean isPubToGroupAndName() { return mBPubToGroupAndName; }
        public int getMode() { return mMode;}
        public int getPlayType() { return mPlayType;}
        public int getScreenOrientation() { return mScreenOrientation;}
    }
}

==> yylivesdk4cloud-audiovideo-2.2.14-sources.jar: com/yy/yylivesdk4cloud/ThunderNotificationInside.java <==
package com.yy.yylivesdk4cloud;

/**
 * Created by dzz on 2018/8/27.
 */

public class ThunderNotificationInside {
    // 接口内部消息起始标记
    public static final int kThunderAPINotification_Start_Tag = 1000;

    // 媒体推送信息返回
    public static final int kThunderAPINotification_PublishVideoCfg = kThunderAPINotification_Start_Tag + 0;


    public static class PublishVideoCfg {
        private int mEncodeFrameRate;
        private int mEncodeBitrate;
        private int mEncodeResolutionWidth;
        private int mEncodeResolutionHeight;
        private int mEncodeType;
        private boolean mBHardwareEncoder;
        private boolean mBMirrorFrontCamera;
        private boolean mBPubToGroupAndName;
        private int mMode;
        private int mPlayType;
        private int mScreenOrientation;

        public PublishVideoCfg(int encodeFrameRate,
                               int encodeBitrate,
                               int encodeResolutionWidth,
                               int encodeResolutionHeight,
                               int encodeType,
                               boolean bHardwareEncoder,
                               boolean bMirrorFrontCamera,
                               boolean bPubToGroupAndName,
                               int mode,
                               int playType,
                               int screenOrientation
                               )
        {
            mEncodeFrameRate = encodeFrameRate;
            mEncodeBitrate = encodeBitrate;
            mEncodeResolutionWidth = encodeResolutionWidth;
            mEncodeResolutionHeight = encodeResolutionHeight;
            mEncodeType = encodeType;
            mBHardwareEncoder = bHardwareEncoder;
            mBMirrorFrontCamera = bMirrorFrontCamera;
            mBPubToGroupAndName = bPubToGroupAndName;
            mMode = mode;
            mPlayType = playType;
            mScreenOrientation = screenOrientation;
        }

        public int getEncodeFrameRate() { return mEncodeFrameRate;}
        public int getEncodeBitrate() { return mEncodeBitrate;}
        public int getEncodeResolutionWidth() { return mEncodeResolutionWidth;}
        public int getEncodeResolutionHeight() { return mEncodeResolutionHeight;}
        public int getEncodeType() { return mEncodeType;}
        public boolean isHardwareEncoder() { return mBHardwareEncoder; }
        public boolean isMirrorFrontCamera() { return mBMirrorFrontCamera; }
        public boolean isPubToGroupAndName() { return mBPubToGroupAndName; }
        public int getMode() { return mMode;}
        public int getPlayType() { return mPlayType;}
        public int getScreenOrientation() { return mScreenOrientation;}
    }
}
